summaryrefslogtreecommitdiff
path: root/compiler/exo-tflite
diff options
context:
space:
mode:
author채성우/On-Device Lab(SR)/Engineer/삼성전자 <sw4670.chae@samsung.com>2019-09-11 17:05:36 +0900
committer박세희/On-Device Lab(SR)/Principal Engineer/삼성전자 <saehie.park@samsung.com>2019-09-11 17:05:36 +0900
commit46c1723bc79f9fe76190b76d4334bd0738a1c145 (patch)
tree5ba51b9e4268f18110846b8c6e4ac757e47d593b /compiler/exo-tflite
parentbf2680218dad9d16a819e7c67a22d30764395e1f (diff)
downloadnnfw-46c1723bc79f9fe76190b76d4334bd0738a1c145.tar.gz
nnfw-46c1723bc79f9fe76190b76d4334bd0738a1c145.tar.bz2
nnfw-46c1723bc79f9fe76190b76d4334bd0738a1c145.zip
[exo-tflite] Rename existing Pad class (#7388)
This commit is for renaming existing Pad class in exo-tflite. Related: #7357 Signed-off-by: seongwoo <sw4670.chae@samsung.com>
Diffstat (limited to 'compiler/exo-tflite')
-rw-r--r--compiler/exo-tflite/src/ExporterUtils.cpp2
-rw-r--r--compiler/exo-tflite/src/ExporterUtils.h2
-rw-r--r--compiler/exo-tflite/src/LogHelper.cpp2
-rw-r--r--compiler/exo-tflite/src/LogHelper.h4
4 files changed, 5 insertions, 5 deletions
diff --git a/compiler/exo-tflite/src/ExporterUtils.cpp b/compiler/exo-tflite/src/ExporterUtils.cpp
index d001cef37..84143d7e9 100644
--- a/compiler/exo-tflite/src/ExporterUtils.cpp
+++ b/compiler/exo-tflite/src/ExporterUtils.cpp
@@ -134,7 +134,7 @@ uint32_t SerializedModelData::registerCustomOpcode(const std::string &custom_op)
return idx;
}
-tflite::Padding getOpPadding(const loco::Pad<2> *pad)
+tflite::Padding getOpPadding(const loco::Padding2D *pad)
{
// VALID padding
if (pad->top() == 0 && pad->bottom() == 0 && pad->left() == 0 && pad->right() == 0)
diff --git a/compiler/exo-tflite/src/ExporterUtils.h b/compiler/exo-tflite/src/ExporterUtils.h
index cf6178592..fedaaaa8a 100644
--- a/compiler/exo-tflite/src/ExporterUtils.h
+++ b/compiler/exo-tflite/src/ExporterUtils.h
@@ -104,7 +104,7 @@ template <> inline bool isNHWC(loco::Permutation<loco::Domain::Filter> *perm)
perm->axis(loco::FilterAxis::Width) == 2 && perm->axis(loco::FilterAxis::Depth) == 3;
}
-tflite::Padding getOpPadding(const loco::Pad<2> *pad);
+tflite::Padding getOpPadding(const loco::Padding2D *pad);
/// @brief Register graph input and output names to SerializedModelData
void registerGraphIOName(loco::Graph *graph, SerializedModelData &gd);
diff --git a/compiler/exo-tflite/src/LogHelper.cpp b/compiler/exo-tflite/src/LogHelper.cpp
index 50377b833..7c2d6f9f7 100644
--- a/compiler/exo-tflite/src/LogHelper.cpp
+++ b/compiler/exo-tflite/src/LogHelper.cpp
@@ -46,7 +46,7 @@ std::ostream &operator<<(std::ostream &os, const loco::TensorShape &tensor_shape
return os;
}
-std::ostream &operator<<(std::ostream &os, const loco::Pad<2> &pad)
+std::ostream &operator<<(std::ostream &os, const loco::Padding2D &pad)
{
os << "[TLBR " << pad.top() << "," << pad.left() << "," << pad.bottom() << "," << pad.right()
<< "]";
diff --git a/compiler/exo-tflite/src/LogHelper.h b/compiler/exo-tflite/src/LogHelper.h
index e7ab6a181..69d81af9e 100644
--- a/compiler/exo-tflite/src/LogHelper.h
+++ b/compiler/exo-tflite/src/LogHelper.h
@@ -45,9 +45,9 @@ std::ostream &operator<<(std::ostream &os, const loco::FilterShape &filter_shape
std::ostream &operator<<(std::ostream &os, const loco::TensorShape &tensor_shape);
/**
* @brief dump Pad<2> values to stream
*/
-std::ostream &operator<<(std::ostream &os, const loco::Pad<2> &pad);
+std::ostream &operator<<(std::ostream &os, const loco::Padding2D &pad);
} // namespace loco
@@ -45,9 +45,9 @@ std::ostream &operator<<(std::ostream &os, const loco::FilterShape &filter_shape
std::ostream &operator<<(std::ostream &os, const loco::TensorShape &tensor_shape);
/**
- * @brief dump Pad<2> values to stream
+ * @brief dump Padding2D values to stream
*/